alias mDragIcon XmDragIcon
alias mDropSiteManager XmDropSiteManager
alias mDragContext XmDragContext
alias mDropTransfer XmDropTransfer
alias mDropSiteUnregister XmDropSiteUnregister
alias mDropSiteStartUpdate XmDropSiteStartUpdate
alias mDropSiteEndUpdate XmDropSiteEndUpdate
